#!/bin/bash
set -x
trap no_ctrlc SIGINT

ctrlc_count=0
function no_ctrlc() {
    let ctrlc_count++
    echo
    if [[ $ctrlc_count == 1 ]]; then
        echo "Stop that."
    elif [[ $ctrlc_count == 2 ]]; then
        echo "Once more and I quit."
    else
        echo "That's it.  I quit."
        exit
    fi
}

set -xe

# Make backup of old changelog
cp debian/changelog ../changelog_backup

old_version="$(dpkg-parsechangelog | grep Version | awk '{ print $2 }')"
old_distribution="$(dpkg-parsechangelog | grep Distribution | awk '{ print $2 }')"

for codename in bookworm bullseye; do #trixie bullseye; do
	old_prefix=""
	[[ "${old_distribution,,}" == "unreleased" ]] && old_prefix="debxx"
	[[ "${old_distribution,,}" == "bullseye" ]]   && old_prefix="deb11"
	[[ "${old_distribution,,}" == "bookworm" ]]   && old_prefix="deb12"
	[[ "${old_distribution,,}" == "trixie" ]]     && old_prefix="deb13"

	prefix=""
	[[ "$codename" == "bullseye" ]] && prefix="deb11"
	[[ "$codename" == "bookworm" ]] && prefix="deb12"
	[[ "$codename" == "trixie" ]]   && prefix="deb13"

	first_dch_line="$(cat debian/changelog | head -n1| sed "s/$old_distribution/$codename/g")"
	first_dch_line="$(echo ${first_dch_line} | head -n1 | sed "s/$old_prefix/${prefix}/g")"

	echo -e "${first_dch_line}\n$(cat debian/changelog | tail -n+2)" > debian/changelog

        version="$(dpkg-parsechangelog | grep Version | awk '{ print $2 }')"
        distribution="$(dpkg-parsechangelog | grep Distribution | awk '{ print $2 }')"

        if [ "$codename" != "$distribution" ]; then
		echo "[FAILED]: changelog target codename must be set to $codename."
		sleep 1
		exit 1
        fi

	debuild --no-lintian -uc -us -d -S

	cd ..
	sbuild -sAd $codename debian-edu-router_"${version}".dsc --no-run-lintian
	debsign debian-edu-router_"${version}"_amd64.changes -k ED9F2F7A36E0D99349CC1940B500EFC78100A778
	dupload -t itzks-debian-production debian-edu-router_"${version}"_amd64.changes
	cd -

        cp ../changelog_backup debian/changelog
done

# Move backup back.
ssh packages.it-zukunft-schule.de -p32032 -litzks-admin REPREPRO_BASE_DIR=/srv/sites/it-zukunft-schule.de/packages/debian reprepro -vvv processincoming itzks-debian-production
